@@ -47,7 +47,7 @@ public:
 class Security: public QWidget, public Ui::Security
 {
 public:
-    Security(QWidget *parent = nullptr) : QWidget(parent) {
+    explicit Security(QWidget *parent = nullptr) : QWidget(parent) {
         setupUi(this);
         walletWarning = new KMessageWidget(this);
         walletWarning->setText(i18n("Storing passwords in config file is insecure!"));
@@ -83,10 +83,7 @@ public:
     }
 
     void fillFrameBuffersCombo() {
-        const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(
-                    QStringLiteral("krfb"), [](const KPluginMetaData & md) {
-            return md.serviceTypes().contains(QStringLiteral("krfb/framebuffer"));
-        });
+        const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("krfb/framebuffer"));
         QSet<QString> unique;
         QVectorIterator<KPluginMetaData> i(plugins);
         i.toBack();
@@ -110,7 +107,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_passwordLineEdit->setVisible(false);
     m_passwordLineEdit->setAlignment(Qt::AlignHCenter);
 
-    QWidget *mainWidget = new QWidget;
+    auto mainWidget = new QWidget;
     m_ui.setupUi(mainWidget);
     m_ui.krfbIconLabel->setPixmap(QIcon::fromTheme(QStringLiteral("krfb")).pixmap(128));
     m_ui.enableUnattendedCheckBox->setChecked(
@@ -255,7 +252,7 @@ void MainWindow::showConfiguration()
         return;
     }
 
-    KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), KrfbConfig::self());
+    auto dialog = new KConfigDialog(this, QStringLiteral("settings"), KrfbConfig::self());
     dialog->addPage(new TCP, i18n("Network"), QStringLiteral("network-wired"));
     dialog->addPage(new Security, i18n("Security"), QStringLiteral("security-high"));
     dialog->addPage(new ConfigFramebuffer, i18n("Screen capture"), QStringLiteral("video-display"));
